package com.bwie.auth.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.bwie.auth.feign.AuthFeign;
import com.bwie.auth.service.AuthService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.User;
import com.bwie.common.domain.response.JwtResponse;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

@Service
public class AuthServiceImpl implements AuthService {
    @Autowired
    private AuthFeign authFeign;
    @Autowired
    private StringRedisTemplate stringRedisTemplate;
    @Autowired
    private HttpServletRequest request;

    @Override
    public Result doLogin(User user) {
        if(StringUtils.isAnyBlank(user.getUserName(),user.getUserPwd())){
            return Result.error("账号和密码不能为空");
        }
        Result<User> userByName = authFeign.findUserByName(user.getUserName());

        User data = userByName.getData();

        if(data==null){
            return Result.error("账号不存在请先去注册");
        }
        if (!data.getUserPwd().equals(user.getUserPwd())){
            return Result.error("密码不正确请重新获取");
        }

        String userKey = UUID.randomUUID().toString().replace("-", "");
        HashMap<String, Object> map = new HashMap<>();
        map.put(JwtConstants.USER_KEY,userKey);

        String token = JwtUtils.createToken(map);
        stringRedisTemplate.opsForValue().set(TokenConstants.LOGIN_TOKEN_KEY+userKey, JSONObject.toJSONString(data),120, TimeUnit.MINUTES);
        JwtResponse jwtResponse = new JwtResponse();
        jwtResponse.setToken(token);
        jwtResponse.setExistTime("120MIN");

        return Result.success(jwtResponse);
    }

    @Override
    public Result info() {
        String token = request.getHeader(TokenConstants.TOKEN);
        String userKey = JwtUtils.getUserKey(token);
        String s = stringRedisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);

        return Result.success(JSONObject.parseObject(s,User.class));
    }
}
